/*  $Id: Command.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

/**
 * command interface.
 * Parameters can be set individualy or all at once.
 * Error handler is used to manage error occuring during command execution. 
 * @version $Id: Command.java 1035 2010-06-15 13:08:33Z sdevaux $
 * @author Sebastien Devaux
 */
public interface Command extends Runnable {
    /**
     * Defines several parameters at once.
     * may use a queryString like syntax to define all parameters.
     * @param paramsSpec parameters definition
     */
    void setParameters(String paramsSpec);
    /**
     * Set one parameter.
     * @param param parameter name.
     * @param value parameter value.
     */
    void setParameter(String param,String value);
    /**
     * Set error handler.
     * @param eh error handler to be used during command execution.
     */
    void setErrorHandler(ErrorHandler eh);
}
